
'                                           EXAMPLE01
'
'                                      ONE LED BLINKS FIVE TIMES
'*************************************************************************************************
'IMPORTANT:  Please run this code and attempt to understand it before advancing to
'            Example02, Example03, etc.  In the future, examples will be added and each will
'            gradually increase in complexity and/or cover a different concept.
'*************************************************************************************************
'                                     
'DIFFICULTY LEVEL: Very easy
'
'PURPOSE:
'  -- The purpose of this example is to demonstrate an extremely simple program that almost anyone
'     will be able to understand. This is a "Hello World" type of program.
'  -- Future examples will become increasingly more complex.
'  -- This program shows how to turn on and off a single LED at port A16 every second.  This
'     on-off sequence will be repeated five times.
'  -- Also, this program explains one way to use WaitCnt to pause program execution.
'  -- Future examples will build on each other; therefore, less internal documentation will be
'     needed.
'  -- Only one of the eight processors is used in this example.
'  -- IT IS ASSUMED THAT THE PROGRAMMER HAS OR IS READING THE PROPELLER'S EXTERNAL DOCUMENTATION
'     AND HAS SOME PREVIOUS PROGRAMMING EXPERIENCE WITH MICROCONTROLLERS. IT IS FURTHER
'     ASSUMED THAT ONE LED IS CORRECTLY CONNECTED TO PORT A16.  IF YOU HAVE THE DEVELOPMENT
'     KIT, THE CONNECTION WILL NOT BE A PROBLEM.
'  -- Every effort has been made to insure that the code in this and future examples
'     runs correctly.
'Submitted by Dave Scanlan, Feb 27, 2006
'File: Example01_BlinkingOneLED.spin       
'*************************************************************************************************
'CORRECT OUTPUT: The LED at port A16 will blink every second, five times.
'*************************************************************************************************
'
'
CON
'Set clock speed to 80 MHz
  _clkmode = xtal1 + pll16x        'Sets the clock speed to 80 MHz using a times 16 multiplier
  _xinfreq = 5_000_000             'Crystal speed: 5 MHz
' 
  High = 1                         'A CONstant used to set an output port to about 3 volts
  Low  = 0                         'A CONstant used to set an output port to about 0 volts
  Out = %1                         'A CONstant used to set a port's direction to Out
' 
VAR
  Byte Pin                         'Declares Pin to be a global VARiable of a type Byte
' 
PUB Start                          'A PUBlick procedure named Start                                                             
  BlinkingLED                      'Calls the PRIvate procedure BlinkingLED
'                                                                                                                               
PRI BlinkingLED                    'A PRIvate procedure named BlinkingLED
  Pin := 16                        'Assigns 16 to the variable Pin                                      
  DirA[Pin] := Out                 'Makes port A16 an output port
  Repeat 5                         'Repeats the code indented under it 5 times
    'TURN THE LED ON AND OFF
    ' -- The LED, at port A16, is on for 1/2 second and off for 1/2 second.
    ' -- The System Counter increments by one for every System Clock pulse. Thus, if the
    '    System Clock is running at 80MHz, the System Counter will increment 80 million times
    '    in one second; and every counter increment will take 12.5ns (1/80MHz).
    '    Each WaitCnt statement below is set to cause a 1/2 second wait:
    '    40_000_000 counter increments * 12.5ns = 500ms (1/2 second)
' 
         OutA[Pin] := High         'LED ON                                      
         WaitCnt(40_000_000 + Cnt) 'ONE-HALF SECOND WAIT
         OutA[Pin] := Low          'LED OFF
         WaitCnt(40_000_000 + Cnt) 'ONE-HALF SECOND WAIT
'
'INDENTION IS IMPORTANT IN SPIN: There are no ENDIFs, END REPEATs, END SUB, etc.