
'                                           EXAMPLE 05
'
'                       USING TWO COGS(PROCESSORS) WITH ARGUMENTS AND PARAMETERS              
'*************************************************************************************************
'IMPORTANT: This example may require an understanding of examples 01, 02, 03, AND 04
'*************************************************************************************************
'WHAT'S NEW IN THIS EXAMPLE:
'
'   ARGUMENTS/PARAMETERS:  Arguments pass values to their corresponding Parameters.
'                          Note: Some programmers use the word "parameter" to refer
'                                to both the argument and its corresponding parameter.
'                                This programmer does not.  Having seperate names makes
'                                it easier to refer to them in the documentation.
'*************************************************************************************************
'
'DIFFICULTY LEVEL: Easy
'
'PURPOSE:
'  -- The purpose of this example is to demonstrate the use of Arguments and Parameters when
'     two Cogs(processors) are running in parallel.
'
'ADDITIONAL INFORMATION:
'  -- Two procedures run in parallel as they did in EXAMPLE 03. This time, however,
'     the WaitCnt time is set by passing two different values to the two procedures by using
'     arguments and parameters.
'
'     The Argument (WaitPeriod_Arg) passes 8_000_000 to its corresponding parameter
'     (WaitPeriod_Par) in one procedure, and 80_000_000 in the other procedure.
'     The result of this is that one LED will blink on and off every 0.2 seconds and
'     the other every 2.0 seconds.
'
'Submitted by Dave Scanlan, March 5, 2006          
'File: Example05_TwoCogsArgParGlobalVar.spin
'*************************************************************************************************
'CORRECT OUTPUT: The LED at A16 will blink on and off every 0.2 seconds and the LED at A17 will
'                blink on and off every 2.0 seconds.  The blinking will occur in parallel, but
'                the LED at A16 will finish ten times faster. Both LEDs will blink five times.   
'*************************************************************************************************
CON
  _clkmode      = xtal1 + pll16x
  _xinfreq      = 5_000_000
' 
  High = 1
  Low  = 0
'
VAR
  Long Stack0[20]                           'Sets up a stack space for a Cog(processor)
  Long Stack1[20]                           'Sets up a stack space for a second Cog(processor)
                                            'long Stack0[20]: Allocates 20 longs for the stack.
                                            'long Stack1[20]: Allocates 20 longs for the stack.
'                                    
  Long WaitPeriod_Arg                       'Arg in WaitPeriod_Arg stands for Argument.
                                            'Sets the rate at which the LED blinks.
' 
'
PUB Start
'
  WaitPeriod_Arg := 8_000_000               '0.1 second wait period
' 
 'Starts a New Cog(Calls BlinkingLED_A16 (WaitPeriod Argument),This Cog uses @stack0)             
  CogNew(BlinkingLED_A16 (WaitPeriod_Arg), @Stack0)
  
  WaitPeriod_Arg := 80_000_000              '1.0 second wait period
  
 'Starts a New Cog(Calls BlinkingLED_A17 (WaitPeriod Argument), This Cog uses @stack1)
  CogNew(BlinkingLED_A17 (WaitPeriod_Arg), @Stack1)
'
'
'LED Blinks Fast
PRI BlinkingLED_A16 (WaitPeriod_Par) | Pin  'Par in WaitPeriod_Par stands for Parameter.
  Pin := 16
  DirA[Pin] := %1
'
  Repeat 5
    OutA[Pin] := High                                                     
    WaitCnt(WaitPeriod_Par + Cnt)            '0.1 second wait period 
    OutA[Pin] := Low                   
    WaitCnt(WaitPeriod_Par + Cnt)            '0.1 second wait period
'
'
'LED Blinks Slowly
PRI BlinkingLED_A17 (WaitPeriod_Par)| Pin    'Par in WaitPeriod_Par stands for Parameter.            
  Pin := 17
  DirA[Pin] := %1
'                 
  Repeat 5
    OutA[Pin] := High                                                     
    WaitCnt(WaitPeriod_Par + Cnt)            '1.0 second wait period  
    OutA[Pin] := Low                   
    WaitCnt(WaitPeriod_Par + Cnt)            '1.0 second wait period   

'INDENTION IS IMPORTANT IN SPIN CODE.

'FOR THE ADVANCED LEARNER:
'  -- Arguments and Parameters are used to help eliminate tightly coupled code. In other words,
'     procedures of code can pass values to each other without using global variables.
'     The use of global variables to pass values between procedures is call Common Coupling,
'     and this we try to avoid. (Use Google Search Words: Common Coupling Structured Design)
'     Because the Argument (WaitPeriod_Arg) was declared as a global variable, two
'     different names were required for an argument and its corresponding parameter. More
'     on this in EXAMPLE 06.)
'  -- In order to keep this example simple, a global variable is used; but in EXAMPLE 06
'     we will show you how to eliminate this global variable by  using local variables
'     instead.
'  -- In Spin, Arguments pass values to their corresponding Parameters "by value".