
'                                           EXAMPLE 06
'
'                  SAME AS EXAMPLE 05, BUT WITH A LOCAL VARIABLE AS THE ARGUMENT              
'*************************************************************************************************
'IMPORTANT: This example WILL require an understanding of examples 01, 02, 03, 04, and 05
'*************************************************************************************************
'WHAT'S NEW IN THIS EXAMPLE:

'   LOCAL VARIABLE AS AN ARGUMENT: In EXAMPLE 05, the argument was a global variable. In this
'                                  example the argument is a local variable.
'
'                                  If a global variable is used as an argument, the exact same
'                                  name cannot be used as the name for the argument's
'                                  corresponding parameter.  This is why two different
'                                  names were used in EXAMPLE 05. (See EXAMPLE 05)
'                 
'                                  In this example, we do not need to make the names different
'                                  because the argument is declared as a local variable.
'                                  Thus, WaitPeriod is used for the argument and the parameter.
'                                  Having the same name makes tracing through the code with
'                                  nested procedural calls, much easier to follow.
'
'   NOTE:  IN ANY COMPUTER LANGUAGE IT IS ALWAYS BEST TO USE A LOCAL VARIABLE WHEN POSSIBLE TO
'          CONTROL COUPLING BETWEEN PROCEDURES.  THE PROGRAMMER SHOULD KEEP THE PROCEDURES IN 
'          ANY PROGRAM LOOSELY COUPLED, NOT TIGHTLY COUPLED.  GLOBAL VARIABLES CAUSE TIGHTLY
'          COUPLED PROCEDURES AND LEAD TO ERRORS THAT ARE DIFFICULT TO TRACE.
'     
'*************************************************************************************************
'
'DIFFICULTY LEVEL: INTERMEDIATE 
'
'PURPOSE:
'  -- The purpose of this example is to show ONE of the benifits for using a local
'     variable as an argument.
'
'ADDITIONAL INFORMATION:
'  -- EXAMPLE 05 where a global variable was used for the argument
'       ARGUMENT NAME                   PARAMETER NAME
'         WaitPeriod_Arg                  WaitPeriod_Par
'
'  -- EXAMPLE 06 where a local variable was used for the argument
'     ARGUMENT NAME                    PARAMETER NAME
'       WaitPeriod                       WaitPeriod
'
'Submitted by Dave Scanlan, March 5, 2006          
'File: Example05_TwoCogsArgParLocalVar.spin
'*************************************************************************************************
'CORRECT OUTPUT: The LED at A16 will blink on and off every 0.2 seconds and the LED at A17 will
'                blink on and off every 2.0 seconds.  The blinking will occur in parallel, but
'                the LED at A16 will finish ten times faster. Both LEDs will blink five times.   
'*************************************************************************************************
CON
  _clkmode      = xtal1 + pll16x
  _xinfreq      = 5_000_000
' 
  High = 1
  Low  = 0
'
VAR
  Long Stack0[20]                        'Sets up a stack space for a Cog(processor)
  Long Stack1[20]                        'Sets up a stack space for a second Cog(processor)
                                         'long Stack0[20]: Allocates 20 longs for the stack.
                                         'long Stack1[20]: Allocates 20 longs for the stack.                                        
  

PUB Start  | WaitPeriod                  'WaitPeriod sets the rate at which the LED blinks.
'
  WaitPeriod := 8_000_000                '0.1 second wait period
  
 'Starts a New Cog(Calls BlinkingLED_A16 (WaitPeriod argument), This Cog uses @stack0)            
  CogNew(BlinkingLED_A16 (WaitPeriod), @Stack0)
  
  WaitPeriod := 80_000_000               '1.0 second wait period
  
 'Starts a New Cog(Calls BlinkingLED_A17 (WaitPeriod argument), This Cog uses @stack1)
  CogNew(BlinkingLED_A17 (WaitPeriod), @Stack1)
'
'
'LED Blinks Fast
PRI BlinkingLED_A16 (WaitPeriod) | Pin    'Par in WaitPeriod_Par stands for Parameter.
  Pin := 16
  DirA[Pin] := %1
'
  Repeat 5
    OutA[Pin] := High                                                     
    WaitCnt(WaitPeriod + Cnt)              '0.1 second wait period   
    OutA[Pin] := Low                   
    WaitCnt(WaitPeriod + Cnt)              '0.1 second wait period
'
'
'LED Blinks Slowly
PRI BlinkingLED_A17 (WaitPeriod)| Pin      'Par in WaitPeriod_Par stands for Parameter.              
  Pin := 17
  DirA[Pin] := %1
'                 
  Repeat 5
    OutA[Pin] := High                                                     
    WaitCnt(WaitPeriod + Cnt)               '1.0 second wait period   
    OutA[Pin] := Low                   
    WaitCnt(WaitPeriod + Cnt)               '1.0 second wait period    

'INDENTION IS IMPORTANT IN SPIN CODE.

'FOR THE ADVANCED LEARNER:
'  -- Arguments and Parameters are used to help eliminate tightly coupled code. 
'     The use of global variables to pass values between procedures is call Common 
'     Coupling, and this we try to avoid.
'  -- Global variables have a strong potential to cause serious errors which are very
'     difficult to locate.
'  -- A FULL EXPLANATION OF GLOBAL VARIABLE EFFECTS WOULD REQUIRE A TWO-HOUR LECTURE...OR LONGER.
'     I suggest a Google search using these words: Common Coupling Structured Design
'  -- Arguments pass values to their corresponding parameters "by value" in Spin.   