'                                      EXAMPLE 09
'
'                           DEBUGGING USING THE VIDEO MONITOR                                 
'****************************************************************************
'IMPORTANT: This example requires an understanding of example 04.
'****************************************************************************
'WHAT'S NEW IN THIS EXAMPLE:
'
'  VideoDisplay.Dec(Value):  Dec(Value) will output any Byte, Word, or Long
'                            as a decimal value.
'
'  VideoDisplay.Hex(Value,#OfDigits): Hex(Value,#OfDigits) will output any 
'                                     Byte, Word, or Long in a Hex format 
'                                     using a specified number of digits.
'
'  VideoDisplay.Bin(Value,#OfDigits): Bin(Value,#OfDigits) will output any
'                                     Byte, Word, or Long in a Binary format
'                                     using a specified number of digits.    
'****************************************************************************
'DIFFICULTY LEVEL: Very easy
'
'PURPOSE:
'  -- Demonstrates how to display on a video monitor the value of any variable
'     during program execution.  It further demonstrates how to monitor the
'     state (HIGH or LOW) of any input port.
'
'Submitted by Dave Scanlan, March 13, 2006         
'File: Example09_DebuggingUsingTheVideoMonitor.spin
'****************************************************************************
'CORRECT OUTPUT: The values of three variables are displayed on the video
'                monitor in Decimal, Hex, and Binary format.
'                After 10 seconds, Pin A1 is monitored and its state is 
'                displayed on the video monitor.
'****************************************************************************
'
CON
  _clkmode = xtal1 + pll16x       
  _xinfreq = 5_000_000
  NewLine = 13
  Out = %1
  In = %0
'
VAR
  Word Value
'
OBJ
  VideoDisplay: "TV_Terminal"                   
'
PUB Start
  VideoDisplay.start             'Initialize VideoDisplay Object
  SetScreenToWhiteOnDarkBlue
  DirA[1] := In                  'Set port A1 to Input
'
  'DISPLAYS VALUE AS DECIMAL
  Value := 500
  VideoDisplay.Dec(Value)         'Displays a decimal value
  'Output on the video monitor:
  '500
  VideoDisplay.Out(NewLine)
' 
  'DISPLAYS VALUE AS HEX
  Value := $FF
  VideoDisplay.Hex(Value,2)       'Displays a hex value using 2 digits
  'Output on the video monitor:
  'FF
  VideoDisplay.Out(NewLine)
'
  'DISPLAYS VALUE AS BINARY
  Value := %0001_0001
  VideoDisplay.Bin(Value,8)       'Displays a binary value using 8 digits
  'Output on the video monitor:
  '00010001
  VideoDisplay.Out(NewLine)
'
  WaitCnt(1_000_000_000 + Cnt)    'Keeps output on the screen for 10 seconds.
' 
  'MONITORS Pin A1
  Repeat                          'Continuously monitors the state of pin A1
    VideoDisplay.Bin(InA[1],1)
    VideoDisplay.Out(NewLine)
    'Output on the video monitor:
    '0 or 1  depending on input state at pin A1
    '0 or 1  depending on input state at pin A1
    '0 or 1  depending on input state at pin A1
    '0 or 1  depending on input state at pin A1
    '0 or 1  depending on input state at pin A1
    '...
'
PRI SetScreenToWhiteOnDarkBlue                  
  VideoDisplay.out(3)                           
  VideoDisplay.out(5)
'
'
'ADDITIONAL INFORMATION: 
'  -- The video signal output is a composite signal.
'  -- TV_Terminal is an object call TV_Terminal.spin found in the
'     "Propeller Tool" subdirectory.                    
'  -- Any name could have been used instead of "VideoDisplay"
'  -- This examples requires an elementary knowledge of OOP.
'  -- This example assumes you have the development kit or a schematic of it.  
'     You will need one of these to generate a composite video out.