
'                                           EXAMPLE 12
'
'                       PROXIMITY DETECTION USING THE SHARP GP2D12 OR GP2D120                 
'*************************************************************************************************
'IMPORTANT: This example may require an understanding of Example 01
'*************************************************************************************************
'WHAT'S NEW IN THIS EXAMPLE:
'
'  CONCEPT NAME: Proximity Detection
'                - This program uses the Sharp GP2D12 which will detect objects at a range
'                  of 10 to 80 cm. The device uses IR for object detection.
'                  -  This device is often used in robotics to sense the presence of objects.
'                  -  This device is inexpensive, but it is non-linear.  See resource below.
'                  -  Resource: www.acroname.com/robotics/info/articles/sharp/sharp.html#s1
'                  -  Refer to the schematic above for the physical interface of the
'                     Sharp GP2D12 to the Propeller.
'*************************************************************************************************
'DIFFICULTY LEVEL:  Very Easy
'
'PURPOSE:  The purpose of this program is to show how to connect a proximity detector to
'          Propeller and how to write the code for the interface.  
'     
'Submitted by Dave Scanlan, April 17, 2006         
'File: Example12_IR.spin
'*************************************************************************************************
'CORRECT OUTPUT:  When an object is detected, the LED at A16 will turn on, and it will stay on
'                 until the object is no longer detected.
'*************************************************************************************************
CON
  _clkmode      = xtal1 + pll16x
  _xinfreq      = 5_000_000
'
  High = 1                         
  Low  = 0                         
  Out = %1
  In = %0
' 
VAR
  Byte Pin
'
PUB Start
  ProximitySensor
'
PRI ProximitySensor
  Pin := 16                           'LED's location is A16.
  DirA[Pin] := Out
  Pin := 1                            'The input from LM339 (voltage comparitor). 
  DirA[Pin] := In  
'
  Repeat                              'Infinite loop
    If InA[1] == High
      OutA[16] := High
    else
      OutA[16] := Low

      
'*************************************************************************************************
'ADDITIONAL INFORMATION:
'  -- Set the variable resistor about midway and it will detect an object at
'     a distance of about 14 cm. Experiment with other settings to get the
'     detection distance you want.
'  -- The Sharp GP2D120 will allow for detection closer to the sensor.  The
'     range is 4 to 30 cm. This program and hookup will work fine for this sensor, also.